==> haskell-timezone-series-0.1.13-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-timezone-series.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timezone-series
version:              0.1.13
visibility:           public
id:                   timezone-series-0.1.13-8lxErw9wrLf6Z6J89uOObG
key:                  timezone-series-0.1.13-8lxErw9wrLf6Z6J89uOObG
license:              BSD-3-Clause
copyright:            Copyright (c) 2010-2021 Yitzchak Gale. All rights reserved.
maintainer:           yitz@sefer.org
author:               Yitzchak Gale
homepage:             http://projects.haskell.org/time-ng/
synopsis:             Enhanced timezone handling for Data.Time
description:
    This package endows Data.Time, from the time
    package, with several data types and functions
    for enhanced processing of timezones. For one way
    to create timezone series, see the timezone-olson
    (<http://hackage.haskell.org/package/timezone-olson>)
    and timezone-olson-th
    (<http://hackage.haskell.org/package/timezone-olson-th>)
    packages.

category:             Data
abi:                  8a7acaae01969d5e0b623d759dc007d4
exposed:              True
exposed-modules:      Data.Time.LocalTime.TimeZone.Series
import-dirs:          /usr/lib/ghc-9.2.8/site-local/timezone-series-0.1.13
library-dirs:         /usr/lib/ghc-9.2.8/site-local/timezone-series-0.1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-timezone-series
hs-libraries:         HStimezone-series-0.1.13-8lxErw9wrLf6Z6J89uOObG
depends:              base-4.16.4.0 deepseq-1.4.6.1 time-1.11.1.1
haddock-interfaces:
    /usr/share/doc/haskell-timezone-series/html/timezone-series.haddock

haddock-html:         /usr/share/doc/haskell-timezone-series/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-timezone-series-0.1.13-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-timezone-series.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 timezone-series
version:              0.1.13
visibility:           public
id:                   timezone-series-0.1.13-21o0dMYZobR86i3h6j9FWj
key:                  timezone-series-0.1.13-21o0dMYZobR86i3h6j9FWj
license:              BSD-3-Clause
copyright:            Copyright (c) 2010-2021 Yitzchak Gale. All rights reserved.
maintainer:           yitz@sefer.org
author:               Yitzchak Gale
homepage:             http://projects.haskell.org/time-ng/
synopsis:             Enhanced timezone handling for Data.Time
description:
    This package endows Data.Time, from the time
    package, with several data types and functions
    for enhanced processing of timezones. For one way
    to create timezone series, see the timezone-olson
    (<http://hackage.haskell.org/package/timezone-olson>)
    and timezone-olson-th
    (<http://hackage.haskell.org/package/timezone-olson-th>)
    packages.

category:             Data
abi:                  8d7cf33c11b61074de509ff80d9ffec5
exposed:              True
exposed-modules:      Data.Time.LocalTime.TimeZone.Series
import-dirs:          /usr/lib/ghc-9.4.8/site-local/timezone-series-0.1.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/timezone-series-0.1.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/timezone-series-0.1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-timezone-series
hs-libraries:         HStimezone-series-0.1.13-21o0dMYZobR86i3h6j9FWj
depends:              base-4.17.2.1 deepseq-1.4.8.0 time-1.12.2
haddock-interfaces:
    /usr/share/doc/haskell-timezone-series/html/timezone-series.haddock

haddock-html:         /usr/share/doc/haskell-timezone-series/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
